@@ -113,6 +113,8 @@ class SynthBase(object):
         self.synth_outcome = None
         self.synth_constant = None
         self.synth_covariates = None
+        self.rmspe_df = None
+        #used in optimization
         self.min_loss = float("inf")
         self.fail_count = 0 #Used to limit number of optimization attempts
 
@@ -237,6 +239,9 @@ class Synth(Inferences, Plot, DataProcessor):
                     self.original_data.control_outcome, self.original_data.control_covariates, 
                     self.original_data, False, n_optim)
         
+        #Compute rmspe_df
+        self._pre_post_rmspe_ratios(None, False)
+        
 
 class DiffSynth(Inferences, Plot, DataProcessor):
 
@@ -249,7 +254,6 @@ class DiffSynth(Inferences, Plot, DataProcessor):
             dataset, outcome_var, id_var, time_var, treatment_period, treated_unit, **kwargs
         )
         self.original_data = SynthBase(**original_checked_input)
-        self.original_data.dataset.to_csv("original_data.csv", index=False, header=True)
 
         #Process differenced data - will be used in inference
         modified_dataset = self.difference_data(dataset, not_diff_cols)
@@ -257,12 +261,14 @@ class DiffSynth(Inferences, Plot, DataProcessor):
             modified_dataset, outcome_var, id_var, time_var, treatment_period, treated_unit, **kwargs
         )
         self.modified_data = SynthBase(**modified_checked_input)
-        self.original_data.dataset.to_csv("second_original_data.csv", index=False, header=True)
 
         #Get synthetic Control
         self.optimize(self.modified_data.treated_outcome, self.modified_data.treated_covariates,
                     self.modified_data.control_outcome, self.modified_data.control_covariates, 
                     self.modified_data, False, n_optim)
+        
+        #Compute rmspe_df
+        self._pre_post_rmspe_ratios(None, False)
 
     def difference_data(self, dataset, not_diff_cols):
         '''
@@ -282,7 +288,7 @@ class DiffSynth(Inferences, Plot, DataProcessor):
         data = self.original_data
 
         #Binary flag for whether there are columns to ignore
-        ignore_some_cols = not_diff_cols == None
+        ignore_all_cols = not_diff_cols == None
 
         #Compute difference of outcome variable
         modified_dataset[data.outcome_var] = modified_dataset.groupby(data.id)[data.outcome_var].apply(lambda unit: unit.interpolate(method='linear', limit_direction="both")).diff()
@@ -293,7 +299,7 @@ class DiffSynth(Inferences, Plot, DataProcessor):
             modified_dataset[col] = modified_dataset.groupby(data.id)[col].apply(lambda unit: unit.interpolate(method='linear', limit_direction="both"))
             
             #Compute change from previous period
-            if ignore_some_cols is not None:
+            if not ignore_all_cols:
                 if col not in not_diff_cols:
                     modified_dataset[col].diff()
 
